# Generated by Django 3.2.18 on 2024-05-06 16:51

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('openlxp_P1_notification', '0001_initial'),
    ]

    operations = [
        migrations.RenameField(
            model_name='template',
            old_name='template_body',
            new_name='message',
        ),
    ]
