# Generated by Django 3.2.18 on 2024-05-15 18:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('openlxp_P1_notification', '0002_rename_template_body_template_message'),
    ]

    operations = [
        migrations.RenameField(
            model_name='recipient',
            old_name='name',
            new_name='first_name',
        ),
        migrations.AddField(
            model_name='recipient',
            name='last_name',
            field=models.CharField(default='name', help_text='Enter recipient name', max_length=200),
            preserve_default=False,
        ),
    ]
